@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -81,7 +81,8 @@ public:
   {
     UnknownState,
     RunningState,
-    PossiblyStoppedState
+    PossiblyStoppedState,
+    OfflineState
   };
 
 
@@ -115,6 +116,7 @@ public:
   typedef boost::weak_ptr<SqlEditorForm> Ptr;
   static SqlEditorForm::Ref create(wb::WBContextSQLIDE *wbsql, const db_mgmt_ConnectionRef &conn);
   static void report_connection_failure(const std::string &error, const db_mgmt_ConnectionRef &target);
+  static void report_connection_failure(const grt::server_denied &info, const db_mgmt_ConnectionRef &target);
 
   void set_tab_dock(mforms::DockingPoint *dp);
 
@@ -169,6 +171,10 @@ private:
 
   mforms::DockingPoint *_tabdock;
 
+  // Set when we triggered a refresh asynchronously.
+  boost::signals2::connection _overviewRefreshPending;
+  boost::signals2::connection _editorRefreshPending;
+
   bool _autosave_disabled;
   bool _loading_workspace;
   bool _cancel_connect;
@@ -242,6 +248,8 @@ private:
 public:
   bool connect(boost::shared_ptr<sql::TunnelConnection> tunnel);
   bool connected() const;
+  void checkIfOffline();
+  bool offline();
   bool ping() const;
   void finish_startup();
   void cancel_query();
@@ -403,8 +411,8 @@ public:
   SqlEditorPanel *new_sql_script_file();
   SqlEditorPanel *new_sql_scratch_area(bool start_collapsed = false);
   void new_scratch_area() { new_sql_scratch_area(false); }
-  void open_file(const std::string &path, bool in_new_tab);
-  void open_file(const std::string &path = "") { open_file(path, true); }
+  void open_file(const std::string &path, bool in_new_tab, bool askForFile = true);
+  void open_file(const std::string &path = "") { open_file(path, true, !path.empty()); }
 
 public:
   void active_schema(const std::string &value);
@@ -439,6 +447,7 @@ public:
 protected:
   DbSqlEditorLog::Ref _log;
   DbSqlEditorHistory::Ref _history;
+  bool _serverIsOffline;
 
 public:
   // Result should be RowId but that requires to change the task callback type (at least for 64bit builds).
