@@ -339,10 +339,13 @@ void GRTManager::initialize(bool init_python, const std::string &loader_module_p
 #ifdef _WIN32
   add_python_module_dir(_grt, _basedir + "\\python");
   add_python_module_dir(_grt, _basedir + "\\modules");
-#elif !defined(__APPLE__)
+#elif __APPLE__
+  add_python_module_dir(_grt, _basedir + "/plugins");
+#else
   std::vector<std::string> path(base::split(_module_pathlist, G_SEARCHPATH_SEPARATOR_S));
   for (std::vector<std::string>::const_iterator i= path.begin(); i != path.end(); ++i)
     add_python_module_dir(_grt, *i);
+  
 #endif
 
   pyobject_initialize();
@@ -788,18 +791,14 @@ int GRTManager::do_scan_modules(const std::string &path, const std::list<std::st
   int c;
 
   if (!g_file_test(path.c_str(), G_FILE_TEST_IS_DIR))
-  {
- //   if (_verbose)
-//      _grt->send_output(strfmt(_("Skipping non-existent module directory '%s'.\n"), path.c_str()));
     return 0;
-  }
 
   if (_verbose)
     _grt->send_output(strfmt(_("Looking for modules in '%s'.\n"), path.c_str()));
   
   try
   {
-    c= _grt->scan_modules_in(path, extensions.empty() ? _module_extensions : extensions, refresh);
+    c= _grt->scan_modules_in(path, _basedir, extensions.empty() ? _module_extensions : extensions, refresh);
   }
   catch (std::exception &exc)
   {
