@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -226,10 +226,13 @@ void DbConnectPanel::init(DbConnection *conn, const db_mgmt_ConnectionRef &defau
   if (!_anonymous_connection->driver().is_valid())
     _anonymous_connection->driver(selected_driver());
   
-  if (default_conn.is_valid())
-    _connection->set_connection_and_update(_anonymous_connection);
-  else
-    _connection->set_connection_keeping_parameters(_anonymous_connection);
+  if (_stored_connection_sel.get_selected_index() == 0)
+  {
+    if (default_conn.is_valid())
+      _connection->set_connection_and_update(_anonymous_connection);
+    else
+      _connection->set_connection_keeping_parameters(_anonymous_connection);
+  }
 }
 
 
@@ -338,10 +341,10 @@ void DbConnectPanel::set_default_host_name(const std::string &host, bool update)
 }
 
 
-void DbConnectPanel::param_value_changed(mforms::View *sender)
+void DbConnectPanel::param_value_changed(mforms::View *sender, bool trim_whitespace)
 {
   std::string param_name= sender->get_name();
-  
+
   if (!_allow_edit_connections && !_updating)
   {
     // if stored connections combo is shown, copy the current connection params to the
@@ -354,10 +357,13 @@ void DbConnectPanel::param_value_changed(mforms::View *sender)
 
   DbDriverParam *param= _connection->get_db_driver_param_handles()->get(param_name);
 
-  param->set_value(grt::StringRef(sender->get_string_value()));
-  
+  if (trim_whitespace)
+    param->set_value(grt::StringRef(base::trim(sender->get_string_value())));
+  else
+    param->set_value(grt::StringRef(sender->get_string_value()));
+
   _connection->save_changes();
-  
+
   std::string error = _connection->validate_driver_params();
   if (error != _last_validation)
     _signal_validation_state_changed(error, error.empty());
@@ -628,10 +634,19 @@ bool DbConnectPanel::test_connection()
   {
     sql::DriverManager *dbc_drv_man= sql::DriverManager::getDriverManager();
     db_mgmt_ConnectionRef connectionProperties = get_be()->get_connection();
+    if (!connectionProperties.is_valid())
+    {
+      db_mgmt_ConnectionRef connection(get_be()->get_grt());
+      connection->owner(get_be()->get_db_mgmt());
+      connection->driver(selected_driver());
+      set_connection(connection);
+      change_active_stored_conn();
+      connectionProperties = get_be()->get_connection();
+    }
     std::string ssl_cipher;
 
     message.append("Host: " + connectionProperties->parameterValues().get_string("hostName") + "\n");
-    message.append("Port: " + grt::IntegerRef(connectionProperties->parameterValues().get_int("port")).repr() + "\n");
+    message.append("Port: " + grt::IntegerRef(connectionProperties->parameterValues().get_int("port")).toString() + "\n");
     message.append("User: " + connectionProperties->parameterValues().get_string("userName") + "\n");
 
     if ( connectionProperties->driver()->name() == "MySQLFabric")
@@ -965,8 +980,8 @@ void DbConnectPanel::set_keychain_password(DbDriverParam *param, bool clear)
   }
   for (grt::DictRef::const_iterator iter = paramValues.begin(); iter != paramValues.end(); ++iter)
   {
-    storage_key = bec::replace_string(storage_key, "%"+iter->first+"%", iter->second.repr());
-    username = bec::replace_string(username, "%"+iter->first+"%", iter->second.repr());
+    storage_key = bec::replace_string(storage_key, "%" + iter->first + "%", iter->second.toString());
+    username = bec::replace_string(username, "%" + iter->first + "%", iter->second.toString());
   }
 
   if (username.empty())
@@ -1121,12 +1136,12 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
 
       // value
       {
-        grt::StringRef value= driver_param->get_value_repr();
+        grt::StringRef value = driver_param->get_value_repr();
         if (value.is_valid())
           ctrl->set_active(*value != "" && *value != "0" && *value != "NULL");
       }
 
-      scoped_connect(ctrl->signal_clicked(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl));
+      scoped_connect(ctrl->signal_clicked(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl, false));
 
       box->add(mforms::manage(ctrl), false, true);
       _views.push_back(ctrl);
@@ -1179,11 +1194,11 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
 
       ctrl->set_size(bounds.width, -1);
 
-      scoped_connect(ctrl->signal_changed(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl));
+      scoped_connect(ctrl->signal_changed(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl, true));
 
       box->add(mforms::manage(ctrl), true, true);
       _views.push_back(ctrl);
-      
+
       break;
     }
     case ::ctText:
@@ -1200,11 +1215,11 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
 
       ctrl->set_size(bounds.width, -1);
 
-      scoped_connect(ctrl->signal_changed(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl));
+      scoped_connect(ctrl->signal_changed(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl, false));
 
       box->add(mforms::manage(ctrl), true, true);
       _views.push_back(ctrl);
-      
+
       break;
     }
     case ::ctFileSelector:
@@ -1220,7 +1235,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
       ctrl->set_size(bounds.width, -1);
 
       ctrl->initialize(initial_value, mforms::OpenFile, "", true,
-        boost::bind(&DbConnectPanel::param_value_changed, this, ctrl));
+        boost::bind(&DbConnectPanel::param_value_changed, this, ctrl, true));
       box->add(mforms::manage(ctrl), true, true);
       _views.push_back(ctrl);
       break;
