@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -142,9 +142,9 @@ bool NodeIdWrapper::is_valid()
 
 //--------------------------------------------------------------------------------------------------
 
-String^ NodeIdWrapper::repr()
+String^ NodeIdWrapper::toString()
 {
-  return CppStringToNative(inner->repr());
+  return CppStringToNative(inner->toString());
 }
 
 //----------------- ListModel ----------------------------------------------------------------------
