@@ -12,25 +12,27 @@
  * This file is dual licensed under LGPL v2.1 and the Scintilla license (http://www.scintilla.org/License.txt).
  */
 
+#include <assert.h>
+#include <sys/time.h>
+
+#include <cstdlib>
+#include <cstring>
+#include <cstdio>
+
+#include <stdexcept>
+#include <vector>
+#include <map>
+
+#import <Foundation/NSGeometry.h>
+
 #import "Platform.h"
 #import "ScintillaView.h"
 #import "ScintillaCocoa.h"
 #import "PlatCocoa.h"
 
-#include <cstring>
-#include <cstdio>
-#include <cstdlib>
-#include <assert.h>
-#include <sys/time.h>
-#include <stdexcept>
-#include <vector>
-#include <map>
-
 #include "StringCopy.h"
 #include "XPM.h"
 
-#import <Foundation/NSGeometry.h>
-
 using namespace Scintilla;
 
 extern sptr_t scintilla_send_message(void* sci, unsigned int iMessage, uptr_t wParam, sptr_t lParam);
@@ -52,7 +54,7 @@ NSRect PRectangleToNSRect(PRectangle& rc)
  */
 PRectangle NSRectToPRectangle(NSRect& rc)
 {
-  return PRectangle(rc.origin.x, rc.origin.y,
+  return PRectangle(static_cast<XYPOSITION>(rc.origin.x), static_cast<XYPOSITION>(rc.origin.y),
 					static_cast<XYPOSITION>(NSMaxX(rc)),
 					static_cast<XYPOSITION>(NSMaxY(rc)));
 }
@@ -539,8 +541,7 @@ void SurfaceImpl::RoundedRectangle(PRectangle rc, ColourDesired fore, ColourDesi
 
   // Create a rectangle with semicircles at the corners
   const int MAX_RADIUS = 4;
-  int radius = Platform::Minimum( MAX_RADIUS, rc.Height()/2 );
-  radius = Platform::Minimum( radius, rc.Width()/2 );
+  const int radius = std::min(MAX_RADIUS, static_cast<int>(std::min(rc.Height()/2, rc.Width()/2)));
 
   // Points go clockwise, starting from just below the top left
   // Corners are kept together, so we can easily create arcs to connect them
@@ -782,10 +783,10 @@ void SurfaceImpl::CopyImageRectangle(Surface &surfaceSource, PRectangle srcRect,
   CGRect drawRect = CGRectMake (0, 0, w, h);
   if (!CGRectEqualToRect (src, dst))
   {
-    float sx = CGRectGetWidth(dst) / CGRectGetWidth(src);
-    float sy = CGRectGetHeight(dst) / CGRectGetHeight(src);
-    float dx = CGRectGetMinX(dst) - (CGRectGetMinX(src) * sx);
-    float dy = CGRectGetMinY(dst) - (CGRectGetMinY(src) * sy);
+    CGFloat sx = CGRectGetWidth(dst) / CGRectGetWidth(src);
+    CGFloat sy = CGRectGetHeight(dst) / CGRectGetHeight(src);
+    CGFloat dx = CGRectGetMinX(dst) - (CGRectGetMinX(src) * sx);
+    CGFloat dy = CGRectGetMinY(dst) - (CGRectGetMinY(src) * sy);
     drawRect = CGRectMake (dx, dy, w*sx, h*sy);
   }
   CGContextSaveGState (gc);
@@ -955,13 +956,13 @@ void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len, XYPOSITION
 		while (ui<fit) {
 			size_t lenChar = utf8LengthFromLead(us[i]);
 			size_t codeUnits = (lenChar < 4) ? 1 : 2;
-			CGFloat xPosition = CTLineGetOffsetForStringIndex(mLine, ui+1, NULL);
+			CGFloat xPosition = CTLineGetOffsetForStringIndex(mLine, ui+codeUnits, NULL);
 			for (unsigned int bytePos=0; (bytePos<lenChar) && (i<len); bytePos++) {
-				positions[i++] = xPosition;
+				positions[i++] = static_cast<XYPOSITION>(xPosition);
 			}
 			ui += codeUnits;
 		}
-		int lastPos = 0;
+		XYPOSITION lastPos = 0.0f;
 		if (i > 0)
 			lastPos = positions[i-1];
 		while (i<len) {
@@ -973,14 +974,14 @@ void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len, XYPOSITION
 			size_t lenChar = Platform::IsDBCSLeadByte(codePage, s[i]) ? 2 : 1;
 			CGFloat xPosition = CTLineGetOffsetForStringIndex(mLine, ui+1, NULL);
 			for (unsigned int bytePos=0; (bytePos<lenChar) && (i<len); bytePos++) {
-				positions[i++] = xPosition;
+				positions[i++] = static_cast<XYPOSITION>(xPosition);
 			}
 			ui++;
 		}
 	} else {	// Single byte encoding
 		for (int i=0;i<len;i++) {
 			CGFloat xPosition = CTLineGetOffsetForStringIndex(mLine, i+1, NULL);
-			positions[i] = xPosition;
+			positions[i] = static_cast<XYPOSITION>(xPosition);
 		}
 	}
 
@@ -992,7 +993,7 @@ XYPOSITION SurfaceImpl::WidthText(Font &font_, const char *s, int len) {
     CFStringEncoding encoding = EncodingFromCharacterSet(unicodeMode, FontCharacterSet(font_));
     textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *reinterpret_cast<QuartzTextStyle*>(font_.GetID()));
 
-	return textLayout->MeasureStringWidth();
+	return static_cast<XYPOSITION>(textLayout->MeasureStringWidth());
   }
   return 1;
 }
@@ -1019,7 +1020,7 @@ XYPOSITION SurfaceImpl::Ascent(Font &font_) {
     return 1;
 
 	float ascent = reinterpret_cast<QuartzTextStyle*>( font_.GetID() )->getAscent();
-	return ascent + 0.5;
+	return ascent + 0.5f;
 
 }
 
@@ -1028,7 +1029,7 @@ XYPOSITION SurfaceImpl::Descent(Font &font_) {
     return 1;
 
 	float descent = reinterpret_cast<QuartzTextStyle*>( font_.GetID() )->getDescent();
-	return descent + 0.5;
+	return descent + 0.5f;
 
 }
 
@@ -1041,14 +1042,13 @@ XYPOSITION SurfaceImpl::ExternalLeading(Font &font_) {
     return 1;
 
 	float leading = reinterpret_cast<QuartzTextStyle*>( font_.GetID() )->getLeading();
-	return leading + 0.5;
+	return leading + 0.5f;
 
 }
 
 XYPOSITION SurfaceImpl::Height(Font &font_) {
 
-	int ht = Ascent(font_) + Descent(font_);
-	return ht;
+	return Ascent(font_) + Descent(font_);
 }
 
 XYPOSITION SurfaceImpl::AverageCharWidth(Font &font_) {
@@ -1057,7 +1057,7 @@ XYPOSITION SurfaceImpl::AverageCharWidth(Font &font_) {
     return 1;
 
   const int sizeStringLength = ELEMENTS( sizeString );
-  int width = WidthText( font_, sizeString, sizeStringLength  );
+  XYPOSITION width = WidthText( font_, sizeString, sizeStringLength  );
 
   return (int) ((width / (float) sizeStringLength) + 0.5);
 }
@@ -1120,15 +1120,13 @@ bool Window::HasFocus()
 
 //--------------------------------------------------------------------------------------------------
 
-static int ScreenMax(NSWindow* win)
+static CGFloat ScreenMax(NSWindow* win)
 {
-  NSScreen* screen = [win screen];
-  if (!screen)
-    screen = [NSScreen mainScreen];
-  NSRect frame = [screen frame];
-  return frame.origin.y + frame.size.height;
+  return NSMaxY([[NSScreen mainScreen] frame]);
 }
 
+//--------------------------------------------------------------------------------------------------
+
 PRectangle Window::GetPosition()
 {
   if (wid)
@@ -1142,7 +1140,7 @@ PRectangle Window::GetPosition()
       NSView* view = reinterpret_cast<NSView*>(idWin);
       win = [view window];
       rect = [view convertRect: [view bounds] toView: nil];
-      rect.origin = [win convertBaseToScreen:rect.origin];
+      rect = [win convertRectToScreen:rect];
     }
     else
     {
@@ -1153,8 +1151,8 @@ PRectangle Window::GetPosition()
     CGFloat screenHeight = ScreenMax(win);
     // Invert screen positions to match Scintilla
     return PRectangle(
-        NSMinX(rect), static_cast<XYPOSITION>(screenHeight - NSMaxY(rect)),
-        NSMaxX(rect), static_cast<XYPOSITION>(screenHeight - NSMinY(rect)));
+        static_cast<XYPOSITION>(NSMinX(rect)), static_cast<XYPOSITION>(screenHeight - NSMaxY(rect)),
+        static_cast<XYPOSITION>(NSMaxX(rect)), static_cast<XYPOSITION>(screenHeight - NSMinY(rect)));
   }
   else
   {
@@ -1175,7 +1173,7 @@ void Window::SetPosition(PRectangle rc)
       // Moves this view inside the parent view
       NSRect nsrc = NSMakeRect(rc.left, rc.bottom, rc.Width(), rc.Height());
       NSView* view = reinterpret_cast<NSView*>(idWin);
-      nsrc.origin = [[view window] convertScreenToBase:nsrc.origin];
+      nsrc = [[view window] convertRectFromScreen:nsrc];
       [view setFrame: nsrc];
     }
     else
@@ -1183,7 +1181,7 @@ void Window::SetPosition(PRectangle rc)
       // NSWindow
       PLATFORM_ASSERT([idWin isKindOfClass: [NSWindow class]]);
       NSWindow* win = reinterpret_cast<NSWindow*>(idWin);
-      int screenHeight = ScreenMax(win);
+      CGFloat screenHeight = ScreenMax(win);
       NSRect nsrc = NSMakeRect(rc.left, screenHeight - rc.bottom,
           rc.Width(), rc.Height());
       [win setFrame: nsrc display:YES];
@@ -1341,8 +1339,8 @@ PRectangle Window::GetMonitorRect(Point)
       CGFloat screenHeight = rect.origin.y + rect.size.height;
       // Invert screen positions to match Scintilla
       return PRectangle(
-          NSMinX(rect), static_cast<XYPOSITION>(screenHeight - NSMaxY(rect)),
-          NSMaxX(rect), static_cast<XYPOSITION>(screenHeight - NSMinY(rect)));
+          static_cast<XYPOSITION>(NSMinX(rect)), static_cast<XYPOSITION>(screenHeight - NSMaxY(rect)),
+          static_cast<XYPOSITION>(NSMaxX(rect)), static_cast<XYPOSITION>(screenHeight - NSMinY(rect)));
     }
   }
   return PRectangle();
@@ -1539,9 +1537,9 @@ private:
   int lineHeight;
   bool unicodeMode;
   int desiredVisibleRows;
-  unsigned int maxItemWidth;
+  XYPOSITION maxItemWidth;
   unsigned int aveCharWidth;
-  unsigned int maxIconWidth;
+  XYPOSITION maxIconWidth;
   Font font;
   int maxWidth;
 
@@ -1623,17 +1621,14 @@ void ListBoxImpl::Create(Window& /*parent*/, int /*ctrlID*/, Scintilla::Point pt
   NSImageCell* imCell = [[[NSImageCell alloc] init] autorelease];
   [colIcon setDataCell:imCell];
   [table addTableColumn:colIcon];
-
   colText = [[NSTableColumn alloc] initWithIdentifier:@"name"];
   [colText setResizingMask:NSTableColumnAutoresizingMask];
   [colText setEditable:NO];
-
   [table addTableColumn:colText];
   ds = [[AutoCompletionDataSource alloc] init];
   [ds setBox:this];
   [table setDataSource: ds];	// Weak reference
   table.delegate = ds;
-
   [scroller setAutoresizingMask: NSViewWidthSizable | NSViewHeightSizable];
   [[winLB contentView] addSubview: scroller];
 
@@ -1676,19 +1671,20 @@ PRectangle ListBoxImpl::GetDesiredRect()
   rcDesired = GetPosition();
 
   // There appears to be an extra pixel above and below the row contents
-  int itemHeight = [table rowHeight] + 2;
+  CGFloat itemHeight = [table rowHeight] + 2;
 
   int rows = Length();
   if ((rows == 0) || (rows > desiredVisibleRows))
     rows = desiredVisibleRows;
 
-  rcDesired.bottom = rcDesired.top + itemHeight * rows;
+  rcDesired.bottom = rcDesired.top + static_cast<XYPOSITION>(itemHeight * rows);
   rcDesired.right = rcDesired.left + maxItemWidth + aveCharWidth;
 
   if (Length() > rows)
   {
     [scroller setHasVerticalScroller:YES];
-    rcDesired.right += [NSScroller scrollerWidth];
+    rcDesired.right += [NSScroller scrollerWidthForControlSize:NSRegularControlSize
+						 scrollerStyle:NSScrollerStyleLegacy];
   }
   else
   {
@@ -1705,7 +1701,7 @@ int ListBoxImpl::CaretFromEdge()
   if ([colIcon isHidden])
     return 3;
   else
-    return 6 + [colIcon width];
+    return 6 + static_cast<int>([colIcon width]);
 }
 
 void ListBoxImpl::Clear()
@@ -1721,7 +1717,7 @@ void ListBoxImpl::Append(char* s, int type)
   ld.Add(count, type, s);
 
   Scintilla::SurfaceImpl surface;
-  unsigned int width = surface.WidthText(font, s, static_cast<int>(strlen(s)));
+  XYPOSITION width = surface.WidthText(font, s, static_cast<int>(strlen(s)));
   if (width > maxItemWidth)
   {
     maxItemWidth = width;
@@ -1733,7 +1729,7 @@ void ListBoxImpl::Append(char* s, int type)
     NSImage* img = it->second;
     if (img)
     {
-      unsigned int widthIcon = img.size.width;
+      XYPOSITION widthIcon = static_cast<XYPOSITION>(img.size.width);
       if (widthIcon > maxIconWidth)
       {
         [colIcon setHidden: NO];
@@ -1889,9 +1885,6 @@ NSImage* ListBoxImpl::ImageForRow(NSInteger row)
 NSString* ListBoxImpl::TextForRow(NSInteger row)
 {
   const char* textString = ld.GetString(row);
-  if (textString == NULL)
-    return @"";
-  
   NSString* sTitle;
   if (unicodeMode)
     sTitle = [NSString stringWithUTF8String:textString];
@@ -2049,7 +2042,7 @@ int Platform::DefaultFontSize()
  * Returns the time span in which two consecutive mouse clicks must occur to be considered as
  * double click.
  *
- * @return
+ * @return time span in milliseconds
  */
 unsigned int Platform::DoubleClickTime()
 {
