@@ -358,7 +358,7 @@ const CGFloat paddingHighlightY = 2;
   [notificationQueue enqueueNotification: notification
                             postingStyle: NSPostWhenIdle
                             coalesceMask: (NSNotificationCoalescingOnName | NSNotificationCoalescingOnSender)
-                                forModes: nil];
+                                forModes: @[NSModalPanelRunLoopMode, NSDefaultRunLoopMode]];
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -395,6 +395,11 @@ ScintillaCocoa::ScintillaCocoa(SCIContentView* view, SCIMarginView* viewMargin)
   idleTimer = NULL;
   observer = NULL;
   layerFindIndicator = NULL;
+  imeInteraction = imeInline;
+  for (TickReason tr=tickCaret; tr<=tickPlatform; tr = static_cast<TickReason>(tr+1))
+  {
+    timers[tr] = nil;
+  }
   Initialise();
 }
 
@@ -435,13 +440,16 @@ void ScintillaCocoa::Initialise()
 void ScintillaCocoa::Finalise()
 {
   ObserverRemove();
-  SetTicking(false);
+  for (TickReason tr=tickCaret; tr<=tickPlatform; tr = static_cast<TickReason>(tr+1))
+  {
+    FineTickerCancel(tr);
+  }
   ScintillaBase::Finalise();
 }
 
 //--------------------------------------------------------------------------------------------------
 
-void ScintillaCocoa::UpdateObserver(CFRunLoopObserverRef observer, CFRunLoopActivity activity, void *info) {
+void ScintillaCocoa::UpdateObserver(CFRunLoopObserverRef /* observer */, CFRunLoopActivity /* activity */, void *info) {
   ScintillaCocoa* sci = reinterpret_cast<ScintillaCocoa*>(info);
   sci->IdleWork();
 }
@@ -517,6 +525,26 @@ static char *EncodedBytes(CFStringRef cfsRef, CFStringEncoding encoding) {
 
 //--------------------------------------------------------------------------------------------------
 
+/**
+ * Convert a core foundation string into a std::string in a particular encoding
+ */
+
+static std::string EncodedBytesString(CFStringRef cfsRef, CFStringEncoding encoding) {
+	const CFRange rangeAll = {0, CFStringGetLength(cfsRef)};
+	CFIndex usedLen = 0;
+	CFStringGetBytes(cfsRef, rangeAll, encoding, '?', false,
+                         NULL, 0, &usedLen);
+	
+	std::string buffer(usedLen, '\0');
+	if (usedLen > 0) {
+		CFStringGetBytes(cfsRef, rangeAll, encoding, '?', false,
+                                 reinterpret_cast<UInt8 *>(&buffer[0]), usedLen, NULL);
+	}
+	return buffer;
+}
+
+//--------------------------------------------------------------------------------------------------
+
 /**
  * Case folders.
  */
@@ -552,9 +580,6 @@ public:
             CFRelease(cfsVal);
 			return lenMapped;
 		}
-		// Something failed so return a single NUL byte
-		folded[0] = '\0';
-		return 1;
 	}
 };
 
@@ -570,7 +595,7 @@ CaseFolder *ScintillaCocoa::CaseFolderForEncoding() {
             // Only for single byte encodings
             for (int i=0x80; i<0x100; i++) {
                 char sCharacter[2] = "A";
-                sCharacter[0] = i;
+                sCharacter[0] = static_cast<char>(i);
                 CFStringRef cfsVal = CFStringCreateWithBytes(kCFAllocatorDefault,
                                                              reinterpret_cast<const UInt8 *>(sCharacter),
                                                              1, encoding, false);
@@ -655,21 +680,10 @@ void ScintillaCocoa::CancelModes() {
 
 //--------------------------------------------------------------------------------------------------
 
-/**
- * Helper function to get the outer container which represents the Scintilla editor on application side.
- */
-ScintillaView* ScintillaCocoa::TopContainer()
-{
-  NSView* container = static_cast<NSView*>(wMain.GetID());
-  return static_cast<ScintillaView*>([[[container superview] superview] superview]);
-}
-
-//--------------------------------------------------------------------------------------------------
-
 /**
  * Helper function to get the scrolling view.
  */
-NSScrollView* ScintillaCocoa::ScrollContainer() {
+NSScrollView* ScintillaCocoa::ScrollContainer() const {
   NSView* container = static_cast<NSView*>(wMain.GetID());
   return static_cast<NSScrollView*>([[container superview] superview]);
 }
@@ -689,7 +703,7 @@ SCIContentView* ScintillaCocoa::ContentView()
 /**
  * Return the top left visible point relative to the origin point of the whole document.
  */
-Scintilla::Point ScintillaCocoa::GetVisibleOriginInMain()
+Scintilla::Point ScintillaCocoa::GetVisibleOriginInMain() const
 {
   NSScrollView *scrollView = ScrollContainer();
   NSRect contentRect = [[scrollView contentView] bounds];
@@ -703,12 +717,13 @@ Scintilla::Point ScintillaCocoa::GetVisibleOriginInMain()
  * in order to make scrolling working properly.
  * The returned value is in document coordinates.
  */
-PRectangle ScintillaCocoa::GetClientRectangle()
+PRectangle ScintillaCocoa::GetClientRectangle() const
 {
   NSScrollView *scrollView = ScrollContainer();
   NSSize size = [[scrollView contentView] bounds].size;
   Point origin = GetVisibleOriginInMain();
-  return PRectangle(origin.x, origin.y, origin.x+size.width, origin.y + size.height);
+  return PRectangle(origin.x, origin.y, static_cast<XYPOSITION>(origin.x+size.width),
+		    static_cast<XYPOSITION>(origin.y + size.height));
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -718,7 +733,7 @@ PRectangle ScintillaCocoa::GetClientRectangle()
  */
 PRectangle ScintillaCocoa::GetClientDrawingRectangle() {
 #if MAC_OS_X_VERSION_MAX_ALLOWED > 1080
-  SCIContentView *content = ContentView();
+  NSView *content = ContentView();
   if ([content respondsToSelector: @selector(setPreparedContentRect:)]) {
     NSRect rcPrepared = [content preparedContentRect];
     if (!NSIsEmptyRect(rcPrepared))
@@ -760,7 +775,7 @@ void ScintillaCocoa::DiscardOverdraw()
 {
 #if MAC_OS_X_VERSION_MAX_ALLOWED > 1080
   // If running on 10.9, reset prepared area to visible area
-  SCIContentView *content = ContentView();
+  NSView *content = ContentView();
   if ([content respondsToSelector: @selector(setPreparedContentRect:)]) {
     content.preparedContentRect = [content visibleRect];
   }
@@ -807,8 +822,7 @@ sptr_t ScintillaCocoa::DirectFunction(sptr_t ptr, unsigned int iMessage, uptr_t
 sptr_t scintilla_send_message(void* sci, unsigned int iMessage, uptr_t wParam, sptr_t lParam)
 {
   ScintillaView *control = reinterpret_cast<ScintillaView*>(sci);
-  ScintillaCocoa* scintilla = [control backend];
-  return scintilla->WndProc(iMessage, wParam, lParam);
+  return [control message:iMessage wParam:wParam lParam:lParam];
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -831,13 +845,24 @@ sptr_t ScintillaCocoa::WndProc(unsigned int iMessage, uptr_t wParam, sptr_t lPar
     case SCI_GETDIRECTPOINTER:
       return reinterpret_cast<sptr_t>(this);
 
+    case SCI_TARGETASUTF8:
+      return TargetAsUTF8(reinterpret_cast<char*>(lParam));
+
+    case SCI_ENCODEDFROMUTF8:
+      return EncodedFromUTF8(reinterpret_cast<char*>(wParam),
+                             reinterpret_cast<char*>(lParam));
+
+    case SCI_SETIMEINTERACTION:
+      // Only inline IME supported on Cocoa
+      break;
+
     case SCI_GRABFOCUS:
       [[ContentView() window] makeFirstResponder:ContentView()];
       break;
 
     case SCI_SETBUFFEREDDRAW:
       // Buffered drawing not supported on Cocoa
-      bufferedDraw = false;
+      view.bufferedDraw = false;
       break;
 
     case SCI_FINDINDICATORSHOW:
@@ -874,32 +899,73 @@ sptr_t ScintillaCocoa::DefWndProc(unsigned int, uptr_t, sptr_t)
 //--------------------------------------------------------------------------------------------------
 
 /**
- * Enables or disables a timer that can trigger background processing at a regular interval, like
- * drag scrolling or caret blinking.
+ * Handle any ScintillaCocoa-specific ticking or call superclass.
  */
-void ScintillaCocoa::SetTicking(bool on)
+void ScintillaCocoa::TickFor(TickReason reason)
 {
-  if (timer.ticking != on)
+  if (reason == tickPlatform)
   {
-    timer.ticking = on;
-    if (timer.ticking)
-    {
-      // Scintilla ticks = milliseconds
-      tickTimer = [NSTimer scheduledTimerWithTimeInterval: timer.tickSize / 1000.0
-						   target: timerTarget
-						 selector: @selector(timerFired:)
-						 userInfo: nil
-						  repeats: YES];
-      timer.tickerID = reinterpret_cast<TickerID>(tickTimer);
-    }
-    else
-      if (timer.tickerID != NULL)
-      {
-        [reinterpret_cast<NSTimer*>(timer.tickerID) invalidate];
-        timer.tickerID = 0;
-      }
+    DragScroll();
+  }
+  else
+  {
+    Editor::TickFor(reason);
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Report that this Editor subclass has a working implementation of FineTickerStart.
+ */
+bool ScintillaCocoa::FineTickerAvailable()
+{
+  return true;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Is a particular timer currently running?
+ */
+bool ScintillaCocoa::FineTickerRunning(TickReason reason)
+{
+  return timers[reason] != nil;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Start a fine-grained timer.
+ */
+void ScintillaCocoa::FineTickerStart(TickReason reason, int millis, int tolerance)
+{
+  FineTickerCancel(reason);
+  NSTimer *fineTimer = [NSTimer scheduledTimerWithTimeInterval: millis / 1000.0
+                                                        target: timerTarget
+                                                      selector: @selector(timerFired:)
+                                                      userInfo: nil
+                                                       repeats: YES];
+  [NSRunLoop.currentRunLoop addTimer: fineTimer forMode: NSModalPanelRunLoopMode];
+  if (tolerance && [fineTimer respondsToSelector: @selector(setTolerance:)])
+  {
+    [fineTimer setTolerance: tolerance / 1000.0];
+  }
+  timers[reason] = fineTimer;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Cancel a fine-grained timer.
+ */
+void ScintillaCocoa::FineTickerCancel(TickReason reason)
+{
+  if (timers[reason])
+  {
+    [timers[reason] invalidate];
+    timers[reason] = nil;
   }
-  timer.ticksToWait = caret.period;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -917,6 +983,7 @@ bool ScintillaCocoa::SetIdle(bool on)
 						 selector: @selector(idleTimerFired:)
 						 userInfo: nil
 						  repeats: YES];
+      [NSRunLoop.currentRunLoop addTimer: idleTimer forMode: NSModalPanelRunLoopMode];
       idler.idlerID = reinterpret_cast<IdlerID>(idleTimer);
     }
     else
@@ -983,7 +1050,7 @@ void ScintillaCocoa::Paste(bool forceRectangular)
 
   pdoc->BeginUndoAction();
   ClearSelection(false);
-  InsertPasteShape(selectedText.Data(), selectedText.Length(),
+  InsertPasteShape(selectedText.Data(), static_cast<int>(selectedText.Length()),
 	  selectedText.rectangular ? pasteRectangular : pasteStream);
   pdoc->EndUndoAction();
 
@@ -1060,7 +1127,8 @@ void ScintillaCocoa::CTPaint(void* gc, NSRect rc) {
 
 void ScintillaCocoa::CallTipMouseDown(NSPoint pt) {
     NSRect rectBounds = [(NSView *)(ct.wDraw.GetID()) bounds];
-    Point location(pt.x, static_cast<XYPOSITION>(rectBounds.size.height - pt.y));
+    Point location(static_cast<XYPOSITION>(pt.x),
+		   static_cast<XYPOSITION>(rectBounds.size.height - pt.y));
     ct.MouseClick(location);
     CallTipClick();
 }
@@ -1121,10 +1189,11 @@ void ScintillaCocoa::ClaimSelection()
  */
 NSPoint ScintillaCocoa::GetCaretPosition()
 {
+  const int line = pdoc->LineFromPosition(sel.RangeMain().caret.Position());
   NSPoint result;
 
-  result.y = pdoc->LineFromPosition(sel.RangeMain().caret.Position());
-  result.x = sel.RangeMain().caret.Position() - pdoc->LineStart(result.y);
+  result.y = line;
+  result.x = sel.RangeMain().caret.Position() - pdoc->LineStart(line);
   return result;
 }
 
@@ -1187,6 +1256,8 @@ void ScintillaCocoa::StartDrag()
 
   inDragDrop = ddDragging;
 
+  FineTickerStart(tickPlatform, timer.tickSize, 0);
+
   // Put the data to be dragged on the drag pasteboard.
   SelectionText selectedText;
   NSPasteboard* pasteboard = [NSPasteboard pasteboardWithName: NSDragPboard];
@@ -1272,8 +1343,8 @@ void ScintillaCocoa::StartDrag()
   SurfaceImpl *sw = new SurfaceImpl();
   SurfaceImpl *pixmap = NULL;
 
-  bool lastHideSelection = hideSelection;
-  hideSelection = true;
+  bool lastHideSelection = view.hideSelection;
+  view.hideSelection = true;
   if (sw)
   {
     pixmap = new SurfaceImpl();
@@ -1281,7 +1352,7 @@ void ScintillaCocoa::StartDrag()
     {
       PRectangle imageRect = rcSel;
       paintState = painting;
-      sw->InitPixMap(client.Width(), client.Height(), NULL, NULL);
+      sw->InitPixMap(static_cast<int>(client.Width()), static_cast<int>(client.Height()), NULL, NULL);
       paintingAllText = true;
       // Have to create a new context and make current as text drawing goes
       // to the current context, not a passed context.
@@ -1293,7 +1364,7 @@ void ScintillaCocoa::StartDrag()
       Paint(sw, client);
       paintState = notPainting;
 
-      pixmap->InitPixMap(imageRect.Width(), imageRect.Height(), NULL, NULL);
+      pixmap->InitPixMap(static_cast<int>(imageRect.Width()), static_cast<int>(imageRect.Height()), NULL, NULL);
 
       CGContextRef gc = pixmap->GetContext();
       // To make Paint() work on a bitmap, we have to flip our coordinates and translate the origin
@@ -1308,7 +1379,7 @@ void ScintillaCocoa::StartDrag()
     sw->Release();
     delete sw;
   }
-  hideSelection = lastHideSelection;
+  view.hideSelection = lastHideSelection;
 
   NSBitmapImageRep* bitmap = NULL;
   if (pixmap)
@@ -1348,6 +1419,7 @@ void ScintillaCocoa::StartDrag()
  */
 NSDragOperation ScintillaCocoa::DraggingEntered(id <NSDraggingInfo> info)
 {
+  FineTickerStart(tickPlatform, timer.tickSize, 0);
   return DraggingUpdated(info);
 }
 
@@ -1390,6 +1462,7 @@ void ScintillaCocoa::DraggingExited(id <NSDraggingInfo> info)
 {
 #pragma unused(info)
   SetDragPosition(SelectionPosition(invalidPosition));
+  FineTickerCancel(tickPlatform);
   inDragDrop = ddNone;
 }
 
@@ -1499,6 +1572,68 @@ bool ScintillaCocoa::GetPasteboardData(NSPasteboard* board, SelectionText* selec
 
 //--------------------------------------------------------------------------------------------------
 
+// Returns the target converted to UTF8.
+// Return the length in bytes.
+int ScintillaCocoa::TargetAsUTF8(char *text)
+{
+  const int targetLength = targetEnd - targetStart;
+  if (IsUnicodeMode())
+  {
+    if (text)
+      pdoc->GetCharRange(text, targetStart, targetLength);
+  }
+  else
+  {
+    // Need to convert
+    const CFStringEncoding encoding = EncodingFromCharacterSet(IsUnicodeMode(),
+                                                         vs.styles[STYLE_DEFAULT].characterSet);
+    const std::string s = RangeText(targetStart, targetEnd);
+    CFStringRef cfsVal = CFStringCreateWithBytes(kCFAllocatorDefault,
+                                                 reinterpret_cast<const UInt8 *>(s.c_str()),
+                                                 s.length(), encoding, false);
+	  
+    const std::string tmputf = EncodedBytesString(cfsVal, kCFStringEncodingUTF8);
+    
+    if (text)
+      memcpy(text, tmputf.c_str(), tmputf.length());
+    CFRelease(cfsVal);
+    return tmputf.length();
+  }
+  return targetLength;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+// Translates a UTF8 string into the document encoding.
+// Return the length of the result in bytes.
+int ScintillaCocoa::EncodedFromUTF8(char *utf8, char *encoded) const
+{
+  const int inputLength = (lengthForEncode >= 0) ? lengthForEncode : strlen(utf8);
+  if (IsUnicodeMode())
+  {
+    if (encoded)
+      memcpy(encoded, utf8, inputLength);
+    return inputLength;
+  }
+  else
+  {
+    // Need to convert
+    const CFStringEncoding encoding = EncodingFromCharacterSet(IsUnicodeMode(),
+                                                         vs.styles[STYLE_DEFAULT].characterSet);
+    
+    CFStringRef cfsVal = CFStringCreateWithBytes(kCFAllocatorDefault,
+                                                 reinterpret_cast<const UInt8 *>(utf8),
+                                                 inputLength, kCFStringEncodingUTF8, false);
+    const std::string sEncoded = EncodedBytesString(cfsVal, encoding);
+    if (encoded)
+      memcpy(encoded, sEncoded.c_str(), sEncoded.length());
+    CFRelease(cfsVal);
+    return sEncoded.length();
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void ScintillaCocoa::SetMouseCapture(bool on)
 {
   capturedMouse = on;
@@ -1531,7 +1666,7 @@ bool ScintillaCocoa::SyncPaint(void* gc, PRectangle rc)
     CGContextSetAllowsFontSmoothing((CGContextRef)gc,
                                     vs.extraFontFlag == SC_EFF_QUALITY_LCD_OPTIMIZED);
 #if MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5
-    if (CGContextSetAllowsFontSubpixelPositioning != NULL)
+    if (&CGContextSetAllowsFontSubpixelPositioning != NULL)
       CGContextSetAllowsFontSubpixelPositioning((CGContextRef)gc,
 						vs.extraFontFlag == SC_EFF_QUALITY_DEFAULT ||
 						vs.extraFontFlag == SC_EFF_QUALITY_LCD_OPTIMIZED);
@@ -1570,7 +1705,7 @@ void ScintillaCocoa::PaintMargin(NSRect aRect)
     CGContextSetAllowsFontSmoothing(gc,
                                     vs.extraFontFlag == SC_EFF_QUALITY_LCD_OPTIMIZED);
 #if MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5
-    if (CGContextSetAllowsFontSubpixelPositioning != NULL)
+    if (&CGContextSetAllowsFontSubpixelPositioning != NULL)
       CGContextSetAllowsFontSubpixelPositioning(gc,
 						vs.extraFontFlag == SC_EFF_QUALITY_DEFAULT ||
 						vs.extraFontFlag == SC_EFF_QUALITY_LCD_OPTIMIZED);
@@ -1610,7 +1745,7 @@ void ScintillaCocoa::WillDraw(NSRect rect)
 /**
  * ScrollText is empty because scrolling is handled by the NSScrollView.
  */
-void ScintillaCocoa::ScrollText(int linesToMove)
+void ScintillaCocoa::ScrollText(int)
 {
 }
 
@@ -1639,7 +1774,7 @@ void ScintillaCocoa::SetHorizontalScrollPos()
 {
   PRectangle textRect = GetTextRectangle();
 
-  int maxXOffset = scrollWidth - textRect.Width();
+  int maxXOffset = scrollWidth - static_cast<int>(textRect.Width());
   if (maxXOffset < 0)
     maxXOffset = 0;
   if (xOffset > maxXOffset)
@@ -1692,7 +1827,7 @@ bool ScintillaCocoa::SetScrollingSize(void) {
 			!Wrapping();
 		if (!showHorizontalScroll)
 			docWidth = clipRect.size.width;
-		NSRect contentRect = {0, 0, docWidth, docHeight};
+		NSRect contentRect = {{0, 0}, {docWidth, docHeight}};
 		NSRect contentRectNow = [inner frame];
 		changes = (contentRect.size.width != contentRectNow.size.width) ||
 			(contentRect.size.height != contentRectNow.size.height);
@@ -1723,8 +1858,8 @@ void ScintillaCocoa::Resize()
  */
 void ScintillaCocoa::UpdateForScroll() {
   Point ptOrigin = GetVisibleOriginInMain();
-  xOffset = ptOrigin.x;
-  int newTop = Platform::Minimum(ptOrigin.y / vs.lineHeight, MaxScrollPos());
+  xOffset = static_cast<int>(ptOrigin.x);
+  int newTop = Platform::Minimum(static_cast<int>(ptOrigin.y / vs.lineHeight), MaxScrollPos());
   SetTopLine(newTop);
 }
 
@@ -1765,7 +1900,7 @@ void ScintillaCocoa::RegisterNotifyCallback(intptr_t windowid, SciNotifyFunc cal
 void ScintillaCocoa::NotifyChange()
 {
   if (notifyProc != NULL)
-    notifyProc(notifyObj, WM_COMMAND, Platform::LongFromTwoShorts(GetCtrlID(), SCEN_CHANGE),
+    notifyProc(notifyObj, WM_COMMAND, Platform::LongFromTwoShorts(static_cast<short>(GetCtrlID()), SCEN_CHANGE),
 	       (uintptr_t) this);
 }
 
@@ -1774,7 +1909,8 @@ void ScintillaCocoa::NotifyChange()
 void ScintillaCocoa::NotifyFocus(bool focus)
 {
   if (notifyProc != NULL)
-    notifyProc(notifyObj, WM_COMMAND, Platform::LongFromTwoShorts(GetCtrlID(), (focus ? SCEN_SETFOCUS : SCEN_KILLFOCUS)),
+    notifyProc(notifyObj, WM_COMMAND, Platform::LongFromTwoShorts(static_cast<short>(GetCtrlID()),
+	       (focus ? SCEN_SETFOCUS : SCEN_KILLFOCUS)),
 	       (uintptr_t) this);
 
   Editor::NotifyFocus(focus);
@@ -1834,9 +1970,13 @@ bool ScintillaCocoa::CanRedo()
 
 void ScintillaCocoa::TimerFired(NSTimer* timer)
 {
-#pragma unused(timer)
-  Tick();
-  DragScroll();
+  for (TickReason tr=tickCaret; tr<=tickPlatform; tr = static_cast<TickReason>(tr+1))
+  {
+    if (timers[tr] == timer)
+    {
+      TickFor(tr);
+    }
+  }
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1964,22 +2104,42 @@ bool ScintillaCocoa::KeyboardInput(NSEvent* event)
 int ScintillaCocoa::InsertText(NSString* input)
 {
   CFStringEncoding encoding = EncodingFromCharacterSet(IsUnicodeMode(),
-                                                         vs.styles[STYLE_DEFAULT].characterSet);
-  CFRange rangeAll = {0, static_cast<CFIndex>([input length])};
-  CFIndex usedLen = 0;
-  CFStringGetBytes((CFStringRef)input, rangeAll, encoding, '?',
-                   false, NULL, 0, &usedLen);
-
-  if (usedLen > 0)
+                                                       vs.styles[STYLE_DEFAULT].characterSet);
+  std::string encoded = EncodedBytesString((CFStringRef)input, encoding);
+  
+  if (encoded.length() > 0)
   {
-    std::vector<UInt8> buffer(usedLen);
-
-    CFStringGetBytes((CFStringRef)input, rangeAll, encoding, '?',
-                       false, buffer.data(),usedLen, NULL);
-
-    AddCharUTF((char*) buffer.data(), static_cast<unsigned int>(usedLen), false);
+    AddCharUTF((char*) encoded.c_str(), static_cast<unsigned int>(encoded.length()), false);
   }
-  return static_cast<int>(usedLen);
+  return static_cast<int>(encoded.length());
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Convert from a range of characters to a range of bytes.
+ */
+NSRange ScintillaCocoa::PositionsFromCharacters(NSRange range) const
+{
+  long start = pdoc->GetRelativePositionUTF16(0, range.location);
+  if (start == INVALID_POSITION)
+    start = pdoc->Length();
+  long end = pdoc->GetRelativePositionUTF16(start, range.length);
+  if (end == INVALID_POSITION)
+    end = pdoc->Length();
+  return NSMakeRange(start, end - start);
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Convert from a range of characters from a range of bytes.
+ */
+NSRange ScintillaCocoa::CharactersFromPositions(NSRange range) const
+{
+  const long start = pdoc->CountUTF16(0, range.location);
+  const long len = pdoc->CountUTF16(range.location, NSMaxRange(range));
+  return NSMakeRange(start, len);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1987,16 +2147,71 @@ int ScintillaCocoa::InsertText(NSString* input)
 /**
  * Used to ensure that only one selection is active for input composition as composition
  * does not support multi-typing.
- * Also drop virtual space as that is not supported by composition.
  */
 void ScintillaCocoa::SelectOnlyMainSelection()
 {
-  SelectionRange mainSel = sel.RangeMain();
-  mainSel.ClearVirtualSpace();
-  sel.SetSelection(mainSel);
+  sel.SetSelection(sel.RangeMain());
   Redraw();
 }
 
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Convert virtual space before selection into real space.
+ */
+void ScintillaCocoa::ConvertSelectionVirtualSpace()
+{
+  FillVirtualSpace();
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Erase all selected text and return whether the selection is now empty.
+ * The selection may not be empty if the selection contained protected text.
+ */
+bool ScintillaCocoa::ClearAllSelections()
+{
+  ClearSelection(true);
+  return sel.Empty();
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Start composing for IME.
+ */
+void ScintillaCocoa::CompositionStart()
+{
+  if (!sel.Empty())
+  {
+    NSLog(@"Selection not empty when starting composition");
+  }
+  pdoc->TentativeStart();
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Commit the IME text.
+ */
+void ScintillaCocoa::CompositionCommit()
+{
+  pdoc->TentativeCommit();
+  pdoc->decorations.SetCurrentIndicator(INDIC_IME);
+  pdoc->DecorationFillRange(0, 0, pdoc->Length());
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Remove the IME text.
+ */
+void ScintillaCocoa::CompositionUndo()
+{
+  pdoc->TentativeUndo();
+}
+
 //--------------------------------------------------------------------------------------------------
 /**
  * When switching documents discard any incomplete character composition state as otherwise tries to
@@ -2157,7 +2372,7 @@ void ScintillaCocoa::ActiveStateChanged(bool isActive)
   if (!isActive) {
     DropCaret();
     //SetFocusState( false );
-    SetTicking( false );
+    FineTickerCancel(tickCaret);
   } else {
     ShowCaretAtCurrentPosition();
   }
@@ -2193,7 +2408,7 @@ void ScintillaCocoa::ShowFindIndicatorForRange(NSRange charRange, BOOL retaining
     CFStringEncoding encoding = EncodingFromCharacterSet(IsUnicodeMode(),
 							 vs.styles[STYLE_DEFAULT].characterSet);
     std::vector<char> buffer(charRange.length);
-    pdoc->GetCharRange(&buffer[0], charRange.location, charRange.length);
+    pdoc->GetCharRange(&buffer[0], static_cast<int>(charRange.location), static_cast<int>(charRange.length));
 
     CFStringRef cfsFind = CFStringCreateWithBytes(kCFAllocatorDefault,
 						  reinterpret_cast<const UInt8 *>(&buffer[0]),
@@ -2202,8 +2417,8 @@ void ScintillaCocoa::ShowFindIndicatorForRange(NSRange charRange, BOOL retaining
     if (cfsFind)
         CFRelease(cfsFind);
     layerFindIndicator.retaining = retaining;
-    layerFindIndicator.positionFind = charRange.location;
-    int style = WndProc(SCI_GETSTYLEAT, charRange.location, 0);
+    layerFindIndicator.positionFind = static_cast<int>(charRange.location);
+    long style = WndProc(SCI_GETSTYLEAT, charRange.location, 0);
     std::vector<char> bufferFontName(WndProc(SCI_STYLEGETFONT, style, 0) + 1);
     WndProc(SCI_STYLEGETFONT, style, (sptr_t)&bufferFontName[0]);
     layerFindIndicator.sFont = [NSString stringWithUTF8String: &bufferFontName[0]];
