@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,6 +22,8 @@
 
 @implementation MCollectionViewItemView
 
+@synthesize owner;
+
 /**
  * Make this view accepting events as first responder to allow it to respond to key events.
  */
@@ -56,7 +58,6 @@
 {
   [NSObject cancelPreviousPerformRequestsWithTarget: self];
   [[NSNotificationCenter defaultCenter] removeObserver: self];
-  [super dealloc];
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -65,27 +66,13 @@
 {
   MCollectionViewItemView *copy = (MCollectionViewItemView *)[super copy];
   if (copy)
-    copy->mOwner = mOwner;
+    copy->owner = owner;
   return copy;
 }
 
-
-- (void) setOwner: (NSCollectionViewItem*) owner
-{
-  mOwner= owner;
-  mIsEditing = NO;
-}
-
 //--------------------------------------------------------------------------------------------------
 
-- (NSCollectionViewItem*) owner
-{
-  return mOwner;
-}
-
-//--------------------------------------------------------------------------------------------------
-
-- (NSView*) hitTest: (NSPoint) aPoint 
+- (NSView*)hitTest: (NSPoint) aPoint
 {
   if (NSPointInRect(aPoint, [self convertRect: [self bounds] toView: [self superview]])) 
     return self;
@@ -97,7 +84,7 @@
 /**
  * Removes any requests for starting delayed inline editing if there are any.
  */
-- (void) cancelPendingInlineEdit
+- (void)cancelPendingInlineEdit
 {
   [NSObject cancelPreviousPerformRequestsWithTarget: self selector: @selector(beginInlineEditing) object: nil];
 }
@@ -107,7 +94,7 @@
 /**
  * Returns the currently active collection view or nil if no one is active (is first responder).
  */
-- (NSCollectionView*) activeCollectionView
+- (NSCollectionView*)activeCollectionView
 {
   NSResponder* currentFirstResponder = [[self window] firstResponder];
   if ([currentFirstResponder isKindOfClass: [NSCollectionView class]])
@@ -124,7 +111,7 @@
 
 //--------------------------------------------------------------------------------------------------
 
-- (void) mouseDown: (NSEvent*) theEvent 
+- (void)mouseDown: (NSEvent*) theEvent
 {
   mMouseDownLocation= [self convertPoint: [theEvent locationInWindow] fromView: nil];
   
@@ -140,7 +127,7 @@
   BOOL shift = (modifiers & NSShiftKeyMask) != 0;
   BOOL command = (modifiers & NSCommandKeyMask) != 0;
   
-  if (!control && !shift && !command)
+  if (!owner.collectionView.allowsMultipleSelection || (!control && !shift && !command))
   {
     if ([[self delegate] respondsToSelector: @selector(clearSelection)]) 
       [[self delegate] clearSelection];
@@ -165,14 +152,11 @@
 
 //--------------------------------------------------------------------------------------------------
 
-- (void) rightMouseDown: (NSEvent*) event
+- (void)rightMouseDown: (NSEvent*) event
 {
-  //[self cancelPendingInlineEdit];
-  
-  //[self setSelected: YES];
   [self mouseDown: event]; // same handling as left mouse click.
 
-  // this will popup the context menu
+  // This will popup the context menu.
   [super rightMouseDown: event];
 }
 
