@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -79,7 +79,7 @@
     
     if (!items.empty())
     {
-      NSMenu *menu= [[[NSMenu alloc] initWithTitle: @""] autorelease];
+      NSMenu *menu= [[NSMenu alloc] initWithTitle: @""];
       [menu setAutoenablesItems: NO];
       
       for (bec::MenuItemList::const_iterator iter= items.begin(); iter != items.end(); ++iter)
