@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,37 +22,11 @@
 
 @implementation WBPaletteTabView
 
-- (CALayer*) shadowLayer;
+- (CALayer*)shadowLayer;
 {
   return nil;
 }
 
-
-
-- (CALayer*) plaqueLayer;
-{
-  // Create a gradient plaque in the tab row area, behind the tabs.
-  CALayer* plaqueLayer = [CALayer layer];
-  
-  CGRect r = [mTabRowLayer bounds];
-  r.size.height = [self tabAreaHeight] - 1;
-  [plaqueLayer setFrame: r];
-  [plaqueLayer setAutoresizingMask: (kCALayerWidthSizable | kCALayerMaxYMargin)];
-  [plaqueLayer setZPosition: -4];
-  
-  NSBundle* b = [NSBundle bundleForClass: [self class]];
-  NSString* path = [b pathForResource: @"TabRowGradient"
-                               ofType: @"png"];
-  mPlaqueImage = [[NSImage alloc] initWithContentsOfFile: path];
-  NSImageRep* rep = [mPlaqueImage representations][0];
-  CGImageRef img = [(id)rep CGImage];
-  [plaqueLayer setContents: (id)img];
-  
-  return plaqueLayer;
-}
-
-
-
 - (WBTabItem*) tabItemWithIdentifier: (id) identifier
                                label: (NSString*) label;
 {
@@ -62,8 +36,6 @@
 	return item;
 }
 
-
-
 - (void) doCustomize;
 {
 	mTabPlacement = WBTabPlacementTop;
@@ -77,15 +49,6 @@
   [mTabView setFrame: r];
 }
 
-
-
-- (void) dealloc
-{
-  [mPlaqueImage release];
-  
-  [super dealloc];
-}
-
 @end
 
 
