@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,32 +17,24 @@
  * 02110-1301  USA
  */
 
-#import <Cocoa/Cocoa.h>
-
 class Recordset;
 
+@protocol GridViewDelegate
+
+- (void)actionTriggered;
+
+@end
+
 @interface MGridView : NSTableView
-{
-  int mSelectedColumnIndex;
-  int mSelectedRowIndex;
-  int mOSelectedColumnIndex;
-  int mOSelectedRowIndex;
 
-  id selectionChangedActionTarget;
-  SEL selectionChangedAction;
-  
-  Recordset *mRecordset;
-}
-
-- (void)setRecordset:(Recordset*)rset;
+@property (weak) id<GridViewDelegate> actionDelegate;
 
 @property (readonly) int selectedColumnIndex;
 @property (readonly) int selectedRowIndex;
 
-- (void)selectCellAtRow:(int)row column:(int)column;
+- (void)setRecordset: (Recordset*)rset;
+- (void)selectCellAtRow: (int)row column: (int)column;
 
-- (void)setSelectionChangedAction:(SEL)aSelector;
-- (void)selectionChangedActionTarget:(id)target;
 @end
 
 
