@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#import <Cocoa/Cocoa.h>
-
 namespace wb {
   class DiagramOptionsBE;
   class WBContextUI;
@@ -26,15 +24,7 @@ namespace wb {
 
 @class MCanvasViewer;
 
-@interface WBDiagramSizeController : NSObject {
-  IBOutlet NSPanel *panel;
-  IBOutlet MCanvasViewer *canvas;
-  IBOutlet NSTextField *nameField;
-  IBOutlet NSTextField *widthField;
-  IBOutlet NSTextField *heightField;
-  
-  wb::DiagramOptionsBE *_be;
-}
+@interface WBDiagramSizeController : NSObject
 
 - (instancetype)initWithWBContext:(wb::WBContextUI*)wbui NS_DESIGNATED_INITIALIZER;
 
