@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,58 +17,45 @@
  * 02110-1301  USA
  */
 
-#import "WBModelSidebarController.h"
-#import "GRTListDataSource.h"
-#import "MCanvasViewer.h"
-#import "WBObjectPropertiesController.h"
-#import "MOutlineView.h"
-#import "MTextImageCell.h"
-#import "GRTIconCache.h"
-
-#include "workbench/wb_context.h"
-#include "workbench/wb_context_ui.h"
-#include "model/wb_history_tree.h"
+#include "wb_context.h"
 #include "model/wb_model_diagram_form.h"
-#include "model/wb_user_datatypes.h"
-#include "model/wb_context_model.h"
 
+#import "WBModelSidebarController.h"
 #import "mforms/../cocoa/MFView.h"
-#import "MCPPUtilities.h"
-
-#include "grtdb/db_object_helpers.h"
-
 
 @implementation WBModelSidebarController
 
-- (void)setupWithWBContextUI:(wb::WBContextUI*)wbui
+- (void)setupWithDiagramForm: (wb::ModelDiagramForm*)form
 {
-  _wbui= wbui;
- 
-  _catalog_tree = _wbui->get_wb()->get_model_context()->create_catalog_tree();
+  _catalog_tree = form->get_catalog_tree();
   [catalogTreeTab setView: nsviewForView(_catalog_tree)];
 
-  _udtlist = _wbui->get_wb()->get_model_context()->create_user_type_list();
+  _udtlist = form->get_wb()->get_model_context()->create_user_type_list();
   [userTypesTab setView: nsviewForView(_udtlist)];
 
-  _history = _wbui->get_wb()->get_model_context()->create_history_tree();
+  _history = form->get_wb()->get_model_context()->create_history_tree();
   [historyTab setView: nsviewForView(_history)];
 }
 
+- (void)setupWithContext:(wb::WBContextModel*)context
+{
+  _udtlist = context->create_user_type_list();
+  [userTypesTab setView: nsviewForView(_udtlist)];
+
+  _history = context->create_history_tree();
+  [historyTab setView: nsviewForView(_history)];
+}
 
 - (void)dealloc
 {
   delete _udtlist;
   delete _history;
   delete _catalog_tree;
-  
-  [super dealloc];
 }
 
-
 - (void)invalidate
 {
   // Since performSelectorOnMainThread could have pending refreshes reset wbui.
-  _wbui = NULL;
 }
 
 //--------------------------------------------------------------------------------------------------
