@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,17 +17,12 @@
  * 02110-1301  USA
  */
 
-#import <Cocoa/Cocoa.h>
-
 #import "WBPluginPanel.h"
 
-@interface WBPluginPanelController : NSObject 
-{
-  NSPanel *_panel;
-  WBPluginPanel *_editor;
-}
+@interface WBPluginPanelController : NSObject
 
-- (instancetype)initWithEditor:(WBPluginPanel*)editor NS_DESIGNATED_INITIALIZER;
+- (instancetype)initWithEditor: (WBPluginPanel*)editor NS_DESIGNATED_INITIALIZER;
 - (void)show:(id)sender;
 - (void)hide:(id)sender;
+
 @end
