@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,18 +22,26 @@
 
 #import "WBPluginPanelController.h"
 
+@interface WBPluginPanelController()
+{
+  NSPanel *_panel;
+  WBPluginPanel *_editor;
+}
+
+@end
+
 @implementation WBPluginPanelController
 
-- (instancetype)initWithEditor:(WBPluginPanel*)editor
+- (instancetype)initWithEditor: (WBPluginPanel*)editor
 {
   self = [super init];
-  if (self)
+  if (self != nil && editor != nil)
   {
     NSRect rect = NSZeroRect;
     rect.size = [editor minimumSize];
 
     _panel = [[NSPanel alloc] initWithContentRect:rect styleMask:0 backing:NSBackingStoreNonretained defer:NO];
-    _editor = [editor retain];
+    _editor = editor;
     
     [_panel setTitle: [_editor title]];
     [_panel setContentView: [_editor topView]];
@@ -43,13 +51,16 @@
   return self;
 }
 
+- (instancetype)init
+{
+  return [self initWithEditor: nil];
+}
 
 - (void)show:(id)sender
 {
   [_panel makeKeyAndOrderFront: nil];
 }
 
-
 - (void)hide:(id)sender
 {
 }
