@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,19 +17,12 @@
  * 02110-1301  USA
  */
 
-#import <Cocoa/Cocoa.h>
 #import "WBPluginEditorBase.h"
 
+@interface WBPluginWindowController : NSObject
 
-@interface WBPluginWindowController : NSObject {
-  WBPluginEditorBase *mPluginEditor;
-  
-  IBOutlet NSWindow *window;
-  IBOutlet NSView *contentView;
-}
+- (instancetype)initWithPlugin: (WBPluginEditorBase*)plugin NS_DESIGNATED_INITIALIZER;
 
-- (instancetype)initWithPlugin:(WBPluginEditorBase*)plugin NS_DESIGNATED_INITIALIZER;
-
-- (IBAction)buttonClicked:(id)sender;
+- (IBAction)buttonClicked: (id)sender;
 
 @end
