@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -292,7 +292,7 @@ namespace MySQL.GUI.Workbench
       set { formBE.set_zoom(value); }
     }
 
-    public bool Closing { get; set; }
+    new public bool Closing { get; set; }
 
     #endregion
 
@@ -415,7 +415,7 @@ namespace MySQL.GUI.Workbench
         DockSideDocument(modelPropertiesForm, false, false);
         DockSideDocument(historyForm, false, false);
 
-        contentSplitContainer.Panel2MinSize = 300;
+        contentSplitContainer.Panel2MinSize = 370;
         mainContentSplitContainer.Panel2MinSize = 200;
       }
       finally
