@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -232,7 +232,7 @@ namespace MySQL.GUI.Workbench
             + Environment.NewLine
             + "Press [OK] to check for a new version and exit the application. "
             + "Press [Cancel] to continue using this version.",
-            "MySQL Worbench Version Outdated", MessageBoxButtons.OKCancel,
+            "MySQL Workbench Version Outdated", MessageBoxButtons.OKCancel,
             MessageBoxIcon.Warning, MessageBoxDefaultButton.Button1) == DialogResult.OK)
           {
             CheckForNewVersion();
@@ -285,7 +285,6 @@ namespace MySQL.GUI.Workbench
           new WbFrontendCallbacks.StrStrStrStrDelegate(mainForm.ShowFileDialog),
           new WbFrontendCallbacks.VoidStrDelegate(mainForm.ShowStatusText),
           new WbFrontendCallbacks.BoolStrStrFloatDelegate(mainForm.ShowProgress),
-          new WbFrontendCallbacks.BoolStrIntStrPtrDelegate(mainForm.RequestInput),
           new WbFrontendCallbacks.CanvasViewStringStringDelegate(mainForm.CreateNewDiagram),
           new WbFrontendCallbacks.VoidCanvasViewDelegate(mainForm.DestroyView),
           new WbFrontendCallbacks.VoidCanvasViewDelegate(mainForm.SwitchedView),
