@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -96,7 +96,7 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
   if (self)
   {
     BOOL tabSwitcherBelow = NO;
-    mTabView = [[[DraggingTabView alloc] initWithFrame: NSMakeRect(0, 0, 100, 100) owner: aTabView] autorelease];
+    mTabView = [[DraggingTabView alloc] initWithFrame: NSMakeRect(0, 0, 100, 100) owner: aTabView];
 
     switch (tabType)
     {
@@ -110,7 +110,7 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
       case mforms::TabViewMainClosable:
         [mTabView setTabViewType: NSNoTabsNoBorder];
         mTabSwitcher = [[MTabSwitcher alloc] initWithFrame: NSMakeRect(0, 0, 100, 26)];
-        [mTabSwitcher setTabStyle: MMainTabSwitcher];
+        mTabSwitcher.tabStyle = MMainTabSwitcher;
         [mTabSwitcher setTabView: mTabView];
         break;
 
@@ -118,7 +118,7 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
       case mforms::TabViewDocumentClosable:
         [mTabView setTabViewType: NSNoTabsNoBorder];
         mTabSwitcher = [[MTabSwitcher alloc] initWithFrame: NSMakeRect(0, 0, 100, 26)];
-        [mTabSwitcher setTabStyle: MEditorTabSwitcher];
+        mTabSwitcher.tabStyle = MEditorTabSwitcher;
         [mTabSwitcher setTabView: mTabView];
         break;
 
@@ -130,14 +130,14 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
       case mforms::TabViewSelectorSecondary:
         [mTabView setTabViewType: NSNoTabsNoBorder];
         mTabSwitcher = [[MTabSwitcher alloc] initWithFrame: NSMakeRect(0, 0, 100, 26)];
-        [mTabSwitcher setTabStyle: MPaletteTabSwitcherSmallText];
+        mTabSwitcher.tabStyle = MPaletteTabSwitcherSmallText;
         [mTabSwitcher setTabView: mTabView];
         break;
 
       case mforms::TabViewEditorBottom:
         [mTabView setTabViewType: NSNoTabsNoBorder];
         mTabSwitcher = [[MTabSwitcher alloc] initWithFrame: NSMakeRect(0, 0, 100, 26)];
-        [mTabSwitcher setTabStyle: MEditorBottomTabSwitcher];
+        mTabSwitcher.tabStyle = MEditorBottomTabSwitcher;
         tabSwitcherBelow = YES;
         [mTabSwitcher setTabView: mTabView];
         break;
@@ -145,7 +145,7 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
       case mforms::TabViewEditorBottomPinnable:
         [mTabView setTabViewType: NSNoTabsNoBorder];
         mTabSwitcher = [[MTabSwitcher alloc] initWithFrame: NSMakeRect(0, 0, 100, 26)];
-        [mTabSwitcher setTabStyle: MEditorBottomTabSwitcherPinnable];
+        mTabSwitcher.tabStyle = MEditorBottomTabSwitcherPinnable;
         tabSwitcherBelow = YES;
         [mTabSwitcher setTabView: mTabView];
         break;
@@ -316,9 +316,7 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
 
 static bool tabview_create(::mforms::TabView *self, ::mforms::TabViewType tabType)
 {
-  [[[MFTabViewImpl alloc] initWithObject:self tabType:tabType] autorelease];
-    
-  return true;  
+  return [[MFTabViewImpl alloc] initWithObject:self tabType:tabType] != nil;
 }
 
 
@@ -374,7 +372,7 @@ static int tabview_add_page(::mforms::TabView *self, mforms::View *tab, const st
     
     if ( tabView )
     {
-      NSTabViewItem *item= [[[NSTabViewItem alloc] initWithIdentifier: [NSString stringWithFormat:@"%p", tab]] autorelease];
+      NSTabViewItem *item= [[NSTabViewItem alloc] initWithIdentifier: [NSString stringWithFormat: @"%p", tab]];
       MFTabViewItemView *view= [[MFTabViewItemView alloc] init];
 
       view->mOwner = tab;
@@ -413,7 +411,6 @@ static void tabview_remove_page(::mforms::TabView *self, mforms::View *tab)
         {
           MFTabViewItemView *view = (MFTabViewItemView *)item.view;
           [[[view subviews] lastObject] removeFromSuperview];
-          [view release];
           
           [tabView->mTabView removeTabViewItem: item];
         }      
@@ -445,11 +442,9 @@ static void tabview_set_allow_reordering(::mforms::TabView *self, bool flag)
   if (self->get_type() != mforms::TabViewEditorBottom && self->get_type() != mforms::TabViewEditorBottomPinnable && self->get_type() == mforms::TabViewDocumentClosable)
     throw std::invalid_argument("TabView is not of a reorderable type\n");
 
-  MFTabViewImpl* tabView = self->get_data();
-  if (tabView)
-  {
-    [tabView->mTabSwitcher setAllowTabReordering: flag];
-  }
+  MFTabViewImpl *tabView = self->get_data();
+  if (tabView != nil)
+    tabView->mTabSwitcher.allowTabReordering = flag;
 }
 
 
