@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,27 +17,7 @@
  * 02110-1301  USA
  */
 
-#import <Cocoa/Cocoa.h>
-
-#import "MFView.h"
-#include "mforms/textentry.h"
-
-/**
- * A special formatter to implement text length limits.
- */
-@interface LimitedTextFieldFormatter : NSFormatter {
-  int maxLength;
-}
-@property  int maximumLength;
-
-@end
-
-@interface MFTextEntryImpl : NSTextField <NSTextFieldDelegate>
-{
-  mforms::TextEntry *mOwner;
-  NSSize mFixedSize;
-  float mMinHeight;
-}
+@interface MFTextEntryImpl : NSObject
 
 @end
 
