@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,13 +17,9 @@
  * 02110-1301  USA
  */
 
-#import <Cocoa/Cocoa.h>
-#import <WebKit/WebKit.h>
-
 #import "MFView.h"
 #import "mforms/WebBrowser.h"
 
-
 @interface MFWebBrowserImpl : NSView {
   mforms::WebBrowser* mOwner;
   WebView* mBrowser;
