@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,11 +19,22 @@
 
 #include "base/geometry.h"
 #include "base/string_utilities.h"
+#include "wb_editor_storednote.h"
 
 #import "WbModelStoredNoteEditor.h"
 #import "MCPPUtilities.h"
 #import "MVerticalLayoutView.h"
 
+@interface StoredNoteEditor()
+{
+  IBOutlet NSTabView *tabView;
+  IBOutlet NSView* editorHost;
+
+  StoredNoteEditorBE *mBackEnd;
+}
+
+@end
+
 @implementation StoredNoteEditor
 
 //--------------------------------------------------------------------------------------------------
@@ -82,7 +93,6 @@
 - (void) dealloc
 {
   delete mBackEnd;
-  [super dealloc];
 }
 
 //--------------------------------------------------------------------------------------------------
