@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,10 +17,7 @@
  * 02110-1301  USA
  */
 
-#ifndef _STDAFX_H_
-#define _STDAFX_H_
-
-#ifdef _WIN32
+#pragma once
 
 #define NOMINMAX
 #define WIN32_LEAN_AND_MEAN 
@@ -28,6 +25,10 @@
 
 using namespace System::Runtime::InteropServices;
 
-#endif // _WIN32
+#include <glib.h>
 
-#endif // _STDAFX_H_
+#include "grts/structs.db.mgmt.h"
+#include "grts/structs.db.mysql.h"
+#include "grts/structs.db.query.h"
+#include "grts/structs.model.h"
+#include "grts/structs.workbench.physical.h"
